#
# spec file for package flint
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define version_unconverted 2.6.3

Name:           flint
%define lname	libflint14
Version:        3.0~7794
Release:        lp152.4.3.1
Summary:        C library for doing number theory
License:        LGPL-2.1-or-later
Group:          Productivity/Scientific/Math
URL:            http://flintlib.org/

#Git-Clone:     https://github.com/wbhart/flint2
Source:         %name-%version_unconverted.tar.xz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  gmp-devel >= 5
BuildRequires:  libtool
BuildRequires:  mpfr-devel >= 3
BuildRequires:  ntl-devel
BuildRequires:  xz

%description
FLINT (Fast Library for Number Theory) is a C library in support of
computations in number theory. It is also a research project into
algorithms in number theory. At this stage, FLINT consists mainly of
fast integer and polynomial arithmetic and linear algebra.

%package -n %lname
Summary:        C library for doing number theory
Group:          System/Libraries

%description -n %lname
FLINT (Fast Library for Number Theory) is a C library in support of
computations in number theory. It is also a research project into
algorithms in number theory. At this stage, FLINT consists mainly of
fast integer and polynomial arithmetic and linear algebra.

%package devel
Summary:        Development files for flint
Group:          Development/Libraries/C and C++
Requires:       %lname = %version

%description devel
FLINT (Fast Library for Number Theory) is a C library in support of
computations in number theory. It is also a research project into
algorithms in number theory. At this stage, FLINT consists mainly of
fast integer and polynomial arithmetic and linear algebra.

This subpackage contains the include files and library links for
developing against the FLINT library.

%prep
%autosetup -p1 -n %name-%version_unconverted

%build
./configure --prefix="%_prefix" --disable-static --reentrant --with-ntl \
	CFLAGS="%optflags" CXXFLAGS="%optflags"
make %{?_smp_mflags} VERBOSE=1

%install
%make_install LIBDIR="%_lib"
rm -f "%buildroot/%_libdir"/*.la
%fdupes %buildroot/%_prefix

%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files -n %lname
%_libdir/libflint.so.14*
%license LICENSE

%files devel
%_includedir/flint/
%_libdir/libflint.so
%doc NEWS

%changelog
* Sat Aug 29 2020 Jan Engelhardt <jengelh@inai.de>
- Update to version 2.6.3 [boo#1169283]
  * New features:
  * Multivariate polynomials over most standard rings (sparse
    distributed)
  * APR-CL primality proving
  * Elliptic Curve integer factoring
  * Pollard rho integer factoring
  * p+1 integer factoring
  * Best of Breed smooth & general integer factoring routine
  * Howell and Strong Echelon form
  * Möller–Granlund precomputed inverses
  * Fibonacci polynomials
  * sqrt of series and polynomials
  * Division of series over Z
  * Shifted Legendre polynomials, Laguerre polynomials, Gegenbauer
    polys.
  * Threading of FFT for integer and polynomial multiplication over
    Z; threading of quadratic sieve for integer factoring; threading
    for multivariate polynomial multiplication, division and GCD;
    threaded multiplication of matrices mod p.
  * For more, see the NEWS file in the flint-devel subpackage.
- Marked as 3.0~7781 (git rev-list --count
  0e8613b3336f356e07f7bbd4bb2ae5eded68ca40..v2.6.3) for Leap 15.2
  since downgrades of the Version field are not easily possible.
- Enable integration with libntl
- Drop 0001-build-provide-autotools-files.patch
* Sun May 28 2017 bwiedemann@suse.com
- Sort input files to make build reproducible (boo#1041090)
* Sun Nov 13 2016 jengelh@inai.de
- Adjust 0001-build-provide-autotools-files.patch for new
  NTL-10.x header file names.
* Sun Mar 13 2016 jengelh@inai.de
- Update to git snapshot of the master branch
  [marked as 3.0~ in openSUSE due to lack of any prospect on what
  the version will be]
  * Add implementation of Moller-Granlund invert_limb
  * Add implementations of n_div2_preinv and n_divrem2_preinv.
  * Add primitive flint exception mechanism.
  * Add n_powmod2_ui_preinv
  * Add exception for impossible inverse to n_invmod and remove resulting exceptions throughout Flint.
  * Remove smooth factorisation since it is completely broken.
- Remove 0002-compile-fixes.diff
* Sat Nov 14 2015 jengelh@inai.de
- Update to new upstream release 2.5.2
  * LLL (rational, Nguyen-Stehle, from Gram matrix, with_removal,
  Storjohann/ULLL)
  * Hermite normal form (naive, xgcd, Domich-Kannan-Trotter,
  Kannan-Bachem, Pernet-Stein)
  * Smith normal form (diagonal, Kannen-Bachem, Iliopoulos)
  * Paterson-Stockmeyer algorithm
  * modular resultant; hgcd resultant; polynomial discriminant
  * multithreaded multimodular Taylor shift
  * multithreaded Brent-Kung composition
  * multithreaded Kaltofen-Shoup distinct degree factorisation
  * multiplication based reduced row echelon form
  * place inline functions in library for foreign function interfaces
  * Primality tests for large integers (Pocklington, Morrison)
  * Probable prime tests for large integers (Lucas, Baillie-PSW,
  strong-psp, Brillhart-Lehmer-Selfridge)
  * CRT for large integers
  * Dixon algorithm for nullspace
  * Brent-Kung composition in irreducibility and distinct degree
  factorisation
  * floating point QR decomposition
  * Schwarz-Rutishauser Gram-Schmidt algorithm
  * Ogita-Rump-Oishi dot product
  * Bodrato matrix squaring
  * matrix concatenation functions
  * additional functions for returning factor of modulus in polys
  over Z/nZ
  * Hadamard matrix construction
  * series addition/subtraction
  * teach flint_printf/sprintf about explicit width format specifiers
* Fri Jun 26 2015 jengelh@inai.de
- Update to new upstream release 2.4.5
  * fixed a severe bug in flint's fmpz_poly_gcd_heuristic
* Thu Feb 19 2015 jengelh@inai.de
- Add 0002-compile-fixes.diff to fend off improper usage of NTL
  headers.
* Mon Oct 20 2014 schwab@suse.de
- Don't use unknown option -mno-popcnt
* Sun Aug 10 2014 jengelh@inai.de
- Update to new upstream release 2.4.4
  * Fix a bug in the ARM assembly
* Fri Feb  7 2014 jengelh@inai.de
- Update to new upstream release 2.4.1
  * C++ expressions template wrapper
  * Fast factorisation of polynomials over Z/nZ
  * improved p-adics
  * polynomials/matrices over p-adics
  * qadics
  * Finite fields (small and large F_q), polynomials/matrices over F_q
  * Finite fields with Zech logarithm representation
  * Fast factorisation of polynomials over F_q
  * Faster Brent-Kung modular composition
  * New prime sieving code
  * Lambert-W function
  * Precomputed inverses for polynomials and large integers
  * Williams' P+1 integer factoring algorithm
  * Harvey's KS2/KS4 polynomial multiplication
  * Faster primality testing up to 64 bits
  * Support for GMP
  * Support for Boehm-Demers-Weiser GC
  * Support for flint extension modules
* Thu Dec  6 2012 jengelh@inai.de
- Initial package (version 2.3+, revision 375f4c8696b4)
  for build.opensuse.org
